@@ -91,6 +91,8 @@ pub struct PyConfig {
     #[cfg(all(Py_3_9, not(Py_3_10)))]
     pub _use_peg_parser: c_int,
     pub tracemalloc: c_int,
+    #[cfg(Py_3_12)]
+    pub perf_profiling: c_int,
     pub import_time: c_int,
     #[cfg(Py_3_11)]
     pub code_debug_ranges: c_int,
@@ -137,6 +139,8 @@ pub struct PyConfig {
     pub use_frozen_modules: c_int,
     #[cfg(Py_3_11)]
     pub safe_path: c_int,
+    #[cfg(Py_3_12)]
+    pub int_max_str_digits: c_int,
     pub pathconfig_warnings: c_int,
     #[cfg(Py_3_10)]
     pub program_name: *mut wchar_t,
@@ -163,7 +167,7 @@ pub struct PyConfig {
     pub run_filename: *mut wchar_t,
     pub _install_importlib: c_int,
     pub _init_main: c_int,
-    #[cfg(Py_3_9)]
+    #[cfg(all(Py_3_9, not(Py_3_12)))]
     pub _isolated_interpreter: c_int,
     #[cfg(Py_3_11)]
     pub _is_python_build: c_int,
